import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import cx from 'classnames';
import ActionableTag from './Actionable';
import StandardTag from './Standard';
import { ACTIONABLE_ONLY_PROPS, STANDARD_ONLY_PROPS, SIZES, LINK_TYPES, DESIGNS } from './constants';
import { filterKeys } from './helpers';
import { jsx as _jsx } from "react/jsx-runtime";

var AtomTag = function AtomTag(props) {
  var design = props.design,
      href = props.href,
      icon = props.icon,
      onClick = props.onClick,
      responsive = props.responsive,
      size = props.size,
      type = props.type;
  var isActionable = onClick || href;
  var classNames = cx('sui-AtomTag', "sui-AtomTag-" + size, design && "sui-AtomTag--" + design, icon && 'sui-AtomTag-hasIcon', responsive && 'sui-AtomTag--responsive', type && "sui-AtomTag--" + type);
  /**
   * Removes all actionable tag props from the react props
   * @return {Object}
   */

  var getStandardProps = function getStandardProps() {
    return filterKeys(props, ACTIONABLE_ONLY_PROPS);
  };
  /**
   * Removes all standard tag props from the react props
   * @return {Object}
   */


  var getActionableProps = function getActionableProps() {
    return filterKeys(props, STANDARD_ONLY_PROPS);
  };

  return isActionable ? /*#__PURE__*/_jsx(ActionableTag, _extends({}, getActionableProps(), {
    className: classNames
  })) : /*#__PURE__*/_jsx(StandardTag, _extends({}, getStandardProps(), {
    className: classNames
  }));
};

AtomTag.displayName = 'AtomTag';
AtomTag.defaultProps = {
  iconPlacement: 'left',
  size: SIZES.MEDIUM
};
export default AtomTag;
export { DESIGNS as atomTagDesigns };
export { LINK_TYPES as linkTypes };
export { SIZES as atomTagSizes };